==> mmidata-0.1.0.tar.gz: mmidata-0.1.0/mmidata/utils/aws.py <==
import boto3

session = boto3.Session()
s3 = session.client('s3')

def get_matching_s3_objects(bucket, prefix="", suffix=""):
    """
    Generate objects in an S3 bucket.

    :param bucket: Name of the S3 bucket.
    :param prefix: Only fetch objects whose key starts with
        this prefix (optional).
    :param suffix: Only fetch objects whose keys end with
        this suffix (optional).
    """
    paginator = s3.get_paginator("list_objects_v2")
    kwargs = {'Bucket': bucket}

    # We can pass the prefix directly to the S3 API.  If the user has passed
    # a tuple or list of prefixes, we go through them one by one.
    if isinstance(prefix, str):
        prefixes = (prefix, )
    else:
        prefixes = prefix

    for key_prefix in prefixes:
        kwargs["Prefix"] = key_prefix

        for page in paginator.paginate(**kwargs):
            try:
                contents = page["Contents"]
            except KeyError:
                break

            for obj in contents:
                key = obj["Key"]
                if key.endswith(suffix):
                    yield obj

def get_matching_s3_keys(bucket, prefix="", suffix=""):
    """
    Generate the keys in an S3 bucket.

    :param bucket: Name of the S3 bucket.
    :param prefix: Only fetch keys that start with this prefix (optional).
    :param suffix: Only fetch keys that end with this suffix (optional).
    """
    for obj in get_matching_s3_objects(bucket, prefix, suffix):
        yield obj["Key"]

def get_obj_from_bucket(bucket, key):
    """
    Get an object from a bucket given its key.

    :param bucket: Name of the S3 bucket.
    :param key: Name of the Object key.
    """
    # TODO: try/catch look for errors here..
    fileobj = s3.get_object(
        Bucket=bucket,
        Key=key
    )
    # TODO: need to know if this returns a string...
    return fileobj['Body'].read()

==> mmidata-0.1.1.tar.gz: mmidata-0.1.1/mmidata/utils/aws.py <==
import boto3

session = boto3.Session()
s3client = session.client('s3')
s3resource = session.resource('s3')


def get_matching_s3_objects(bucket, prefix="", suffix=""):
    """
    Generate objects in an S3 bucket.

    :param bucket: Name of the S3 bucket.
    :param prefix: Only fetch objects whose key starts with
        this prefix (optional).
    :param suffix: Only fetch objects whose keys end with
        this suffix (optional).
    """
    paginator = s3client.get_paginator("list_objects_v2")
    kwargs = {'Bucket': bucket}

    # We can pass the prefix directly to the S3 API.  If the user has passed
    # a tuple or list of prefixes, we go through them one by one.
    if isinstance(prefix, str):
        prefixes = (prefix, )
    else:
        prefixes = prefix

    for key_prefix in prefixes:
        kwargs["Prefix"] = key_prefix

        for page in paginator.paginate(**kwargs):
            try:
                contents = page["Contents"]
            except KeyError:
                break

            for obj in contents:
                key = obj["Key"]
                if key.endswith(suffix):
                    yield obj

def get_matching_s3_keys(bucket, prefix="", suffix=""):
    """
    Generate the keys in an S3 bucket.

    :param bucket: Name of the S3 bucket.
    :param prefix: Only fetch keys that start with this prefix (optional).
    :param suffix: Only fetch keys that end with this suffix (optional).
    """
    for obj in get_matching_s3_objects(bucket, prefix, suffix):
        yield obj["Key"]

def get_obj_from_bucket(bucket, key):
    """
    Get an object from a bucket given its key.

    :param bucket: Name of the S3 bucket.
    :param key: Name of the Object key.
    """
    # TODO: try/catch look for errors here..
    fileobj = s3client.get_object(
        Bucket=bucket,
        Key=key
    )
    # TODO: need to know if this returns a string...
    return fileobj['Body'].read()
